@@ -224,6 +224,7 @@ def upload(identifier, files,
            retries=None,
            retries_sleep=None,
            debug=None,
+           validate_identifier=None,
            request_kwargs=None,
            **get_item_kwargs):
     """Upload files to an item. The item will be created if it does not exist.
@@ -276,6 +277,10 @@ def upload(identifier, files,
     :param debug: (optional) Set to True to print headers to stdout, and exit without
                   sending the upload request.
 
+    :type validate_identifier: bool
+    :param validate_identifier: (optional) Set to True to validate the identifier before
+                                uploading the file.
+
     :param \*\*kwargs: Optional arguments that ``get_item`` takes.
 
     :returns: A list of :py:class:`requests.Response` objects.
@@ -294,6 +299,7 @@ def upload(identifier, files,
                        retries=retries,
                        retries_sleep=retries_sleep,
                        debug=debug,
+                       validate_identifier=validate_identifier,
                        request_kwargs=request_kwargs)
 
 
@@ -313,6 +319,7 @@ def download(identifier,
              ignore_errors=None,
              on_the_fly=None,
              return_responses=None,
+             no_change_timestamp=None,
              **get_item_kwargs):
     """Download files from an item.
 
@@ -390,7 +397,8 @@ def download(identifier,
                       item_index=item_index,
                       ignore_errors=ignore_errors,
                       on_the_fly=on_the_fly,
-                      return_responses=return_responses)
+                      return_responses=return_responses,
+                      no_change_timestamp=no_change_timestamp)
     return r
 
 
@@ -476,6 +484,7 @@ def search_items(query,
                  fields=None,
                  sorts=None,
                  params=None,
+                 full_text_search=None,
                  archive_session=None,
                  config=None,
                  config_file=None,
@@ -496,6 +505,10 @@ def search_items(query,
     :param params: (optional) The URL parameters to send with each request sent to the
                    Archive.org Advancedsearch Api.
 
+    :type full_text_search: bool
+    :param full_text_search: (optional) Query the archive.org Full Text Search API
+                             [default: False].
+
     :type config: dict
     :param secure: (optional) Configuration options for session.
 
@@ -532,6 +545,7 @@ def search_items(query,
                                         fields=fields,
                                         sorts=sorts,
                                         params=params,
+                                        full_text_search=full_text_search,
                                         request_kwargs=request_kwargs,
                                         max_retries=max_retries)
 
