@@ -28,12 +28,17 @@ options:
     -m, --metadata=<key:value>...  Metadata to add to your new item, if you are moving
                                    the file to a new item.
     -H, --header=<key:value>...    S3 HTTP headers to send with your request.
+
+examples:
+    # Turn off backups
+    ia copy <src-identifier>/<src-file> <dest-identifier>/<dest-file> -H x-archive-keep-old-version:0
 """
 from __future__ import print_function, absolute_import
 import sys
 
 from docopt import docopt, printable_usage
 from schema import Schema, Use, Or, And, SchemaError
+from six.moves.urllib import parse
 
 import internetarchive as ia
 from internetarchive.cli.argparser import get_args_dict
@@ -91,14 +96,13 @@ def main(argv, session, cmd='copy'):
         print('{0}\n{1}'.format(str(exc), usage), file=sys.stderr)
         sys.exit(1)
 
-    args['--header']['x-amz-copy-source'] = '/{}'.format(src_path)
+    args['--header']['x-amz-copy-source'] = '/{}'.format(parse.quote(src_path))
     args['--header']['x-amz-metadata-directive'] = 'COPY'
-    args['--header']
     # Add keep-old-version by default.
     if 'x-archive-keep-old-version' not in args['--header']:
         args['--header']['x-archive-keep-old-version'] = '1'
 
-    url = '{}//s3.us.archive.org/{}'.format(session.protocol, dest_path)
+    url = '{}//s3.us.archive.org/{}'.format(session.protocol, parse.quote(dest_path))
     req = ia.iarequest.S3Request(url=url,
                                  method='PUT',
                                  metadata=args['--metadata'],
