@@ -33,14 +33,16 @@ options:
     -d, --dry-run                            Print URLs to stdout and exit.
     -i, --ignore-existing                    Clobber files already downloaded.
     -C, --checksum                           Skip files based on checksum [default: False].
-    -R, --retries=<retries>                  Set number of retries to <retries> [default: 5]
+    -R, --retries=<retries>                  Set number of retries to <retries> [default: 5].
     -I, --itemlist=<file>                    Download items from a specified file. Itemlists should
                                              be a plain text file with one identifier per line.
     -S, --search=<query>                     Download items returned from a specified search query.
     -P, --search-parameters=<key:value>...   Download items returned from a specified search query.
     -g, --glob=<pattern>                     Only download files whose filename matches the
                                              given glob pattern.
-    -f, --format=<format>...                 Only download files of the specified format(s).
+    -f, --format=<format>...                 Only download files of the specified format.
+                                             Use this option multiple times to download multiple
+                                             formats.
                                              You can use the following command to retrieve
                                              a list of file formats contained within a given
                                              item:
@@ -58,6 +60,7 @@ options:
     --no-change-timestamp                    Don't change the timestamp of downloaded files to reflect
                                              the source material.
     -p, --parameters=<key:value>...          Parameters to send with your query (e.g. `cnt=0`).
+    -a, --download-history                   Do not download any files from the history dir.
 """
 from __future__ import print_function, absolute_import
 import os
@@ -98,6 +101,7 @@ def main(argv, session):
         '--search-parameters': Use(lambda x: get_args_dict(x, query_string=True)),
         '--on-the-fly': Use(bool),
         '--no-change-timestamp': Use(bool),
+        '--download-history': Use(bool),
         '--parameters': Use(lambda x: get_args_dict(x, query_string=True)),
     })
 
@@ -112,8 +116,8 @@ def main(argv, session):
                 raise(SchemaError(None, '--glob and --format cannot be used together.'))
 
     except SchemaError as exc:
-        sys.stderr.write('{0}\n{1}\n'.format(
-            str(exc), printable_usage(__doc__)))
+        print('{0}\n{1}'.format(
+            str(exc), printable_usage(__doc__)), file=sys.stderr)
         sys.exit(1)
 
     retries = int(args['--retries'])
@@ -128,8 +132,8 @@ def main(argv, session):
                                            params=args['--search-parameters'])
             total_ids = _search.num_found
             if total_ids == 0:
-                print('error: the query "{0}" '
-                      'returned no results'.format(args['--search']), file=sys.stderr)
+                print('error: the query "{0}" returned no results'.format(
+                    args['--search']), file=sys.stderr)
                 sys.exit(1)
             ids = _search
         except ValueError as e:
@@ -161,8 +165,8 @@ def main(argv, session):
             try:
                 assert len(f) == 1
             except AssertionError:
-                sys.stderr.write('error: {0}/{1} does not exist!\n'.format(
-                    identifier, args['<file>'][0]))
+                print('error: {0}/{1} does not exist!'.format(
+                    identifier, args['<file>'][0]), file=sys.stderr)
                 sys.exit(1)
             if six.PY2:
                 stdout_buf = sys.stdout
@@ -193,6 +197,7 @@ def main(argv, session):
                 continue
 
         # Otherwise, download the entire item.
+        ignore_history_dir = True if not args['--download-history'] else False
         _errors = item.download(
             files=files,
             formats=args['--format'],
@@ -209,7 +214,8 @@ def main(argv, session):
             ignore_errors=True,
             on_the_fly=args['--on-the-fly'],
             no_change_timestamp=args['--no-change-timestamp'],
-            params=args['--parameters']
+            params=args['--parameters'],
+            ignore_history_dir=ignore_history_dir,
         )
         if _errors:
             errors.append(_errors)
