@@ -30,12 +30,12 @@ import hashlib
 import os
 import re
 import sys
-from collections import Mapping
 from itertools import starmap
 from xml.dom.minidom import parseString
 
 import six
 from six.moves import zip_longest
+from six.moves.collections_abc import Mapping
 
 
 def deep_update(d, u):
@@ -56,13 +56,28 @@ def map2x(func, *iterables):
     return starmap(func, zipped)
 
 
-def validate_ia_identifier(string):
+class InvalidIdentifierException(Exception):
+    pass
+
+
+def validate_s3_identifier(string):
     legal_chars = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789._-'
     # periods, underscores, and dashes are legal, but may not be the first
     # character!
-    assert all(string.startswith(c) is False for c in ['.', '_', '-'])
-    assert 100 >= len(string) >= 3
-    assert all(c in legal_chars for c in string)
+    if any(string.startswith(c) is True for c in ['.', '_', '-']):
+        raise InvalidIdentifierException('Identifier cannot begin with periods ".", underscores '
+                                        '"_", or dashes "-".')
+
+    if len(string) > 100 or len(string) < 3:
+        raise InvalidIdentifierException('Identifier should be between 3 and 80 characters in '
+                                        'length.')
+
+    if any(c not in legal_chars for c in string):
+        raise InvalidIdentifierException('Identifier can only contain alphanumeric characters, '
+                                        'periods ".", underscores "_", or dashes "-". However, '
+                                        'identifier cannot begin with periods, underscores, or '
+                                        'dashes.')
+
     return True
 
 
@@ -235,21 +250,23 @@ def recursive_file_count(files, item=None, checksum=False):
                 is_dir = False
         if is_dir:
             for x, _ in iter_directory(f):
-                lmd5 = get_md5(open(x, 'rb'))
+                if checksum is True:
+                    with open(x, 'rb') as fh:
+                        lmd5 = get_md5(fh)
+                    if lmd5 in md5s:
+                        continue
+                total_files += 1
+        else:
+            if checksum is True:
+                try:
+                    with open(f, 'rb') as fh:
+                        lmd5 = get_md5(fh)
+                except TypeError:
+                    # Support file-like objects.
+                    lmd5 = get_md5(f)
                 if lmd5 in md5s:
                     continue
-                else:
-                    total_files += 1
-        else:
-            try:
-                lmd5 = get_md5(open(f, 'rb'))
-            except TypeError:
-                # Support file-like objects.
-                lmd5 = get_md5(f)
-            if lmd5 in md5s:
-                continue
-            else:
-                total_files += 1
+            total_files += 1
     return total_files
 
 
@@ -312,11 +329,11 @@ def reraise_modify(caught_exc, append_msg, prepend=False):
 
 def remove_none(obj):
     if isinstance(obj, (list, tuple, set)):
-        l = type(obj)(remove_none(x) for x in obj if x)
+        lst = type(obj)(remove_none(x) for x in obj if x)
         try:
-            return [dict(t) for t in {tuple(sorted(d.items())) for d in l}]
+            return [dict(t) for t in {tuple(sorted(d.items())) for d in lst}]
         except (AttributeError, TypeError):
-            return l
+            return lst
     elif isinstance(obj, dict):
         return type(obj)((remove_none(k), remove_none(v))
                          for k, v in obj.items() if k is not None and v)
